@@ -2,7 +2,7 @@ from __future__ import annotations
 
 from tcsoa.gen.BusinessObjects import Discipline
 from tcsoa.gen.Server import ServiceData
-from tcsoa.utils import TcBaseObj
+from tcsoa.base import TcBaseObj
 from dataclasses import dataclass
 
 
