@@ -2,7 +2,7 @@ from tcsoa.gen.EditContext._2015_07.services import DataManagementService as imp
 from tcsoa.gen.EditContext._2016_04.services import DataManagementService as imp1
 from tcsoa.gen.EditContext._2016_10.services import DataManagementService as imp2
 from tcsoa.gen.EditContext._2014_12.services import DataManagementService as imp3
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class DataManagementService(TcService):
