@@ -1,10 +1,10 @@
 from __future__ import annotations
 
-from tcsoa.gen.Internal.Mmv._2012_09.SpatialStructureManagement import GetSpatialCellsReadTicketsResponse, AcquireSpatialHierarchyResponse, SearchScope, SpatialHierCellInfo, GetNodeBBoxIn, AcquireSpatialHierarchyIn, GetNodeBBoxResponse, IsSpatialHierarchyIn, IsSpatialHierarchyLatestResponse, CreateMmvCursorResponse, ReleaseSpatialHierarchyIn
+from tcsoa.gen.Internal.Mmv._2012_09.SpatialStructureManagement import GetNodeBBoxIn, GetNodeBBoxResponse, AcquireSpatialHierarchyResponse, CreateMmvCursorResponse, IsSpatialHierarchyIn, GetSpatialCellsReadTicketsResponse, SearchScope, AcquireSpatialHierarchyIn, ReleaseSpatialHierarchyIn, SpatialHierCellInfo, IsSpatialHierarchyLatestResponse
 from tcsoa.gen.BusinessObjects import BusinessObject
 from typing import List
 from tcsoa.gen.Server import ServiceData
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class SpatialStructureManagementService(TcService):
