@@ -2,7 +2,7 @@ from tcsoa.gen.Internal_ProductConfiguratorAw._2017_12.services import Configura
 from tcsoa.gen.Internal_ProductConfiguratorAw._2020_05.services import ConfiguratorManagementService as imp1
 from tcsoa.gen.Internal_ProductConfiguratorAw._2018_05.services import ConfiguratorManagementService as imp2
 from tcsoa.gen.Internal_ProductConfiguratorAw._2020_12.services import ConfiguratorManagementService as imp3
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class ConfiguratorManagementService(TcService):
