@@ -1,5 +1,5 @@
 from tcsoa.gen.Internal_Reports._2007_06.services import BOMRollupService as imp0
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class BOMRollupService(TcService):
