@@ -1,7 +1,7 @@
 from __future__ import annotations
 
-from tcsoa.utils import TcService
-from tcsoa.gen.Internal.Structure._2020_12.WhereUsed import WhereUsedOutput, WhereUsedInput
+from tcsoa.base import TcService
+from tcsoa.gen.Internal.Structure._2020_12.WhereUsed import WhereUsedInput, WhereUsedOutput
 
 
 class WhereUsedService(TcService):
