@@ -1,5 +1,5 @@
 from tcsoa.gen.Internal_Workflowaw._2020_12.services import WorkflowService as imp0
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class WorkflowService(TcService):
