@@ -1,5 +1,5 @@
 from tcsoa.gen.OfficeOnline._2017_11.services import OfficeOnlineService as imp0
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class OfficeOnlineService(TcService):
