@@ -5,7 +5,7 @@ from tcsoa.gen.Reports._2008_12.services import CrfReportsService as imp3
 from tcsoa.gen.Reports._2010_04.services import CrfReportsService as imp4
 from tcsoa.gen.Reports._2015_10.services import CrfReportsService as imp5
 from tcsoa.gen.Reports._2008_06.services import CrfReportsService as imp6
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class CubeReportsService(TcService):
