@@ -1,5 +1,5 @@
 from tcsoa.gen.WProxy._2014_10.services import ProxyLinkService as imp0
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class ProxyLinkService(TcService):
